@@ -1,12 +1,18 @@
 import os
 import subprocess
 from pyngrok import ngrok
+try:
+    from google.colab import drive
+    colab_env = True
+except ImportError:
+    colab_env = False
 
 
 class ColabCode:
-    def __init__(self, port=10000, password=None):
+    def __init__(self, port=10000, password=None, gcloud=False):
         self.port = port
         self.password = password
+        self._mount = gcloud
         self._install_code()
         self._start_server()
         self._run_code()
@@ -27,6 +33,8 @@ class ColabCode:
 
     def _run_code(self):
         os.system(f"fuser -n tcp -k {self.port}")
+        if self._mount and colab_env:
+            drive.mount("/content/drive")
         if self.password:
             code_cmd = f"PASSWORD={self.password} code-server --port {self.port} --disable-telemetry"
         else:
